ΦID -- Integrated Information Decomposition
-------------------------------------------

.. image:: https://github.com/Imperial-MIND-lab/integrated-info-decomp/actions/workflows/tests.yml/badge.svg
  :target: https://github.com/Imperial-MIND-lab/integrated-info-decomp/actions/workflows/tests.yml
  :alt: tests status

.. image:: https://github.com/Imperial-MIND-lab/integrated-info-decomp/actions/workflows/docs.yml/badge.svg
  :target: https://imperial-mind-lab.github.io/integrated-info-decomp/
  :alt: docs status

This is a Python library developed to facilitate the computation of Integrated Information Decomposition (ΦID) for both continuous and discrete data.
It serves as an equivalent to the original Matlab toolbox, allowing researchers and enthusiasts to leverage Python's extensive ecosystem for analyzing complex systems and neural data.

Installation
------------

The library will be available for installation via pip. You can install the latest version using the following command:

.. code-block:: bash

    pip install git+https://github.com/Imperial-MIND-lab/integrated-info-decomp.git


Citation
--------

If you use :code:`phyid` in your research, please cite the following papers: 
-Mediano, Rosas, et al. (2021) Towards an extended taxonomy of information dynamics via Integrated Information Decomposition. arXiv.
-Luppi et al. (2022) A synergistic core for human brain evolution and cognition. Nature Neuroscience 25, 771–782.

